Project::OSiRiON - Git repositories
Project::OSiRiON
News . About . Screenshots . Downloads . Forum . Wiki . Tracker . Git
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStijn Buys <ingar@osirion.org>2008-02-05 00:10:02 +0000
committerStijn Buys <ingar@osirion.org>2008-02-05 00:10:02 +0000
commit95ca0e469ef856c0182bb0da411e4417391e3780 (patch)
treea07db9b9d726d175d8305dc3cc5520b8a70f7a73 /src/client/console.h
parentcf61370df80de6dc659dbd9b803c973b300c1b4c (diff)
renamed client and server application objects
cleaned up namespaces
Diffstat (limited to 'src/client/console.h')
-rw-r--r--src/client/console.h56
1 files changed, 21 insertions, 35 deletions
diff --git a/src/client/console.h b/src/client/console.h
index c0d485f..9eeb57e 100644
--- a/src/client/console.h
+++ b/src/client/console.h
@@ -18,49 +18,35 @@
namespace client {
-/// client console implementation
-class Console : public sys::ConsoleInterface {
-public:
- Console();
+/// the client console
+namespace console {
- /// stream to send normal messages too
- virtual std::ostream & messagestream();
+/// initialize client console
+/** Adds the engine functions for the client console
+ */
+void init();
- /// stream to send warning messages too
- virtual std::ostream & warningstream();
+/// shutdown the client console
+/** Removes the engine functions for the client console
+ */
+void shutdown();
- /// stream to send error messages too
- virtual std::ostream & errorstream();
+/// flush buffer messages and print to stdout
+void flush();
- /// stream to send debug messages too
- virtual std::ostream & debugstream();
+/// draw the console
+void draw();
- /// flush buffer
- void flush();
-
- /// draw the console
- void draw();
+/// toggle the console on or off
+void toggle();
- /// toggle the console on or off
- void toggle();
-
- /// true of the console is visible
- inline bool visible() { return console_visible; }
+/// handle keyboard input
+void handle_keyreleased(SDL_keysym* keysym);
- /// toggle handle keyboard input
- void handle_keyreleased(SDL_keysym* keysym);
-
-protected:
- /// console text buffer
- std::stringstream buffer;
-
- /// console text data
- std::deque<std::string> text;
+/// true of the console is visible
+bool visible();
-private:
- std::string input;
- bool console_visible;
-};
+}
}